globals [

  maximum-iterations               ; used in the run-length procedure to determine the maximum length of the model run.


  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;; the following globals are only used ;;;
  ;;; for monitoring and reporting        ;;;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  mean_LeadD                       ; for reporting average EE values of District leaders agents per tick
  mean_ConformD                    ; for reporting average EE values of District conformists agents per tick
  mean_SaD                        ; for reporting average EE values of District Stigma-avoiders agents per tick
  meanD                            ; for reporting average EE values of District agents per tick
  SdD                              ; for reporting standard deviation of District agents per tick
  mean_LeadND                      ; for reporting average EE values of non-District leaders agents per tick
  mean_ConformND                   ; for reporting average EE values of non-District conformists agents per tick
  mean_SaND                       ; for reporting average EE values of non-District Stigma-avoiders agents per tick
  meanND                           ; for reporting average EE values of non-District agents per tick
  SdND                             ; for reporting standard deviation of non-District agents per tick
  owner_change                     ; for verification, counter recording the number of agents who change owner type at point of sale

]


patches-own [

  district-area                    ; defines the area as within or outside of the district
  yscale                           ; variable used to create a scale of EE values throughout the world at setup

]


turtles-own [

  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;; agent spatial variables ;;;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  District?                        ; a turtle value reporting the district-area patch value they are on
  peer-group               ; this is the value that non-District agents use to define the scale of their neighborhood peer group. It identifies other turtles based on the neighborhood shape on the interface slider

  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;; agent variables for assessing retrofits ;;;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  Owner_type                       ; holds the information for building owner type (leader, conformist, Stigma-avoider)
  Goal                             ; goal determined by type
  Perceived_benefit                ; the value an agent has for a unit of EEv upgrade with respect to the agent's existing EEv level; Perceived_benefit equation differs by building owner type
  Cost                             ; the cost of a unit of EEv upgrade with respect to the agent's existing EEv level; The cost equation is the same for all building owner types
  EEv                              ; a measure of the energy efficiency value/index of a building (0-100% efficient, so value between 0-1)
  NIR                              ; temporary variable to hold the value of EEv increase due to neighbor influenced retrofits
  NR                               ; temporary variable to hold the additional value of normal upgrades above the NIR upgrade
  Degrade                          ; temporary variable to hold the value of the amount of degradation per iteration

  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;; variable used for time dependent procedures ;;;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  counter                          ; variable to count years (ticks) used by the normal upgrades, bring up to code at sale, and owner type change allowed at sale procedures

]


to setup

  ca                               ; clear initial conditions. Ticks will be reset at the end
  run-length                       ; determine the length of the model run. Baseline = 100; for testing purposes, the option of 1000 is also included
  setup-patches                    ; create the district and non-district area in patches. Patches also set the value from which the EE value scale is taken
  setup-agents                     ; Agents are created that have characteristics of both building energy efficiency values and building owner characteristics
  update_visuals                   ; to see the initial interface visualization after setup
  reset-ticks                      ; starts the tick counter
  output-initial-results           ; This procedure prints the requested values at time step zero

end


to run-length                                               ; this procedure sets maximum iterations at one of the two durations below

  if time = "100 years" [set maximum-iterations 100]     ; the baseline model is set to run 100 years (1 tick = 1 year)
  if time = "1000 test" [set maximum-iterations 1000]       ; 1000 is included as an option for testing purposes

end


to setup-patches

  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;; create building agents ;;;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  ask patches [                                            ; sprout one bulding on each patch

    sprout 1                                               ; sprout is used because turtle breed and orientation are not needed for this model
    set yscale (pycor / max-pycor)                         ; create a scaled value normalized between 0-1 based on the y value (to be used to set initial EEv)

  ]

  ;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;; Create District and ;;;
  ;;; non-District areas  ;;;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;


  ask patches with [pxcor > 25 ] [                         ; create a district on the right side of the world
    set district-area true
    ;  set pcolor 59                                       ; for verification
  ]
  ask patches with [pxcor <= 25 ] [                        ; create a non-district on the left side of the world. Note: there's one more column of non-District than District (odd number of x-coordinates with 0,0)
    set district-area false
    ;  set pcolor red                                      ; for verification
  ]

  if separate-areas = "District_separation"[               ; this procedure is used to test whether Districts and non-Districts have spillover effects. The default is set to district_separation to evaluate the behavior in each area separately

    ask turtles-on patches with [pxcor < 27 and pxcor > 23 ] [     ; creates the separation between District and non-Districts by killing agents (having no buildings) betwen the two areas (neighborhoods only extend to in-radius 3, as defined in a later procedure)
      die
    ]

  ]


end


to setup-agents                                            ; This procedure assigns building and building owner values (this version of the model represents building characteristics and building owner values in the same agent)

    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;; identify agents in district ;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  ask turtles-on patches with [district-area = true] [
    set District? true                                     ; ID buildings within a District (transfer the District designation from patches to turtles)
;    set color red                                         ; verification
  ]
      ask turtles-on patches with [district-area = false] [
    set District? false                                    ; ID buildings outside of a District (transfer the District designation from patches to turtles)
;    set color 59                                          ; verification

  ]

    ;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;; assign agent values ;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;

  ask turtles [

    set shape "house"                                      ; for interface visualization

    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;; values for retrofit decision ;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    set Owner_type "conformist"                              ; to get the proportions according to the slider, all start at conformist then are reassigned

    ifelse District? = true [ set peer-group other turtles with [District? = true]]                 ; for agents in District, the peer group includes all members of the District
    [                                                                                                       ; for agents not in District, the peer group is defined by the neighborhood shape and size by the chooser on the interface
      if neighborhood = "neighbors" [ set peer-group (turtles-on neighbors)]                        ; neighbors is included, but note for comparative purposes that it has a different shape than in-radius
      if neighborhood = "in-radius 1 neighbors" [ set peer-group other turtles in-radius-nowrap 1 ] ; Note: nowrap prevents turtles on edges from assessing neighbors on the other side of the world
      if neighborhood = "in-radius 2 neighbors" [ set peer-group other turtles in-radius-nowrap 2 ]
      if neighborhood = "in-radius 3 neighbors" [ set peer-group other turtles in-radius-nowrap 3 ]

    ]

    set counter random 20                                  ; start with randomness in agents' individual counters; the counter is used in the following procedures: normal upgrade, ownership type change allowed, and bring up to code
    set EEv yscale                                         ; start with an EEv scale between 0-1 (using the agent's y-axis value to create a scale of EEv for initial conditions)

        ;;;;;;;;;;;;;;;;;;;;;;;;
        ;;; EEv verification ;;;
        ;;;;;;;;;;;;;;;;;;;;;;;;

    ; show "EEv " print EEv
    ; if EEv < 0 [ show "<0" print EEv ]
    ; if EEv > 1 [ show ">1" print EEv ]
  ]

  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;; reassign turtle Owner_type from conformist   ;;;
  ;;; to the other two building owner strategies ;;;
  ;;; based on the interface sliders             ;;;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  Ask n-of ((%-Leaders / 100) * count turtles) turtles with [ Owner_type = "conformist"] [set Owner_type "leader"]
  Ask n-of ((%-Stigma-avoiders / 100) * count turtles) turtles with [ Owner_type = "conformist"][set Owner_type "Stigma-avoider"]

        ;;;;;;;;;;;;;;;;;;;;
        ;;; verification ;;;
        ;;;;;;;;;;;;;;;;;;;;

        ; show "EEv LeadersND, ConformistsND, Stigma-avoidersND, LeadersD, ConformistsD, Stigma-avoidersD"
        ; print mean [EEv] of turtles with [ District? != true and Owner_type = "leader"]
        ; print mean [EEv] of turtles with [ District? != true and Owner_type = "conformist"]
        ; print mean [EEv] of turtles with [ District? != true and Owner_type = "Stigma-avoider"]
end


to go

  if ticks = maximum-iterations [               ; the model is set to run 100 years (ticks). If this value is reached, the model stops and exports the results
    output-results
    stop
    ]
  implement_policy                              ; if enabled on the interface, this procedure checks if the counter reaches 20 and runs the scenarios: new owner type allowed and bring up to code
  retrofit_decision                             ; this procedure calculates Neighbor-influenced retrofits (NIR) and Normal retrofits (NR)
  calc_degradation_rate                         ; calculate the projected decline of EE based on the annual degradation rate (which depends on the EEv). This represents the effect of weather and age
  update_values                                 ; update the EE value of the building each time step. = EEv + neighbor_influenced_retrofit + normal_retrofit - Degradation
  update_visuals                                ; update building color on the interface to reflect EEv
  output-results                                ; print the results
  reset_temp_values                             ; reset the temporary variables for the next iteration
  tick                                          ; register a time step and it updates monitors and plots

end

to implement_policy

  ask turtles [
    if counter = 20 [                           ; check if the 20 year mark has been reached
      if new_owner_at_sale = "yes" [            ; procedure to test the scenario of allowing ownership type to change (proportions of building owner types in the world are maintained according to initial conditions)
        new_owner_type_allowed
      ]

      if upgrade_to_code_at_sale = "yes" [      ; procedure to test the scenario of at the point of sale (at 20 years), bringing low EEv buildings up to the energy code level set by the interface slider
        bring_up_to_code
      ]
    ]
  ]

end


to retrofit_decision                            ; NIR will hold the calculated value of projected EE gains from neighbor influenced retrofits                             ;

  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;; agents compare their EEv ;;;
  ;;; with their neighbors     ;;;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  ask turtles [

    calc_neighbor_values                                    ; this procedure updates agents' goal, perceived benefit and cost at every iteration

    if goal > EEv and Perceived_benefit > cost [            ; THIS IS THE KEY MECHANISM OF NIER: Peer groups influence building owner motivation to retrofit when peers have a higher EEv than the calling turtle and the perceived benefit is greater than the cost (which depends on owner type)
      let GapToGoal (goal - EEv)                            ; the GapToGoal value measures the difference between an agent's current EEv and their goal value (determined by building owner type and peer group value)
      let Perceived_Net_benefit (Perceived_benefit - Cost)  ; Perceived_net_benefit is the benefit that the owner will gain above the cost
      set NIR (GapToGoal * Perceived_Net_benefit)           ; the neighbor-influenced retrofit is the portion of the EEv gap (goal from peer group) that the owner perceives as economically feasible to retrofit (perceived_net_benefit)

    ]

    ;if counter < 20 [ print counter ]                      ; verification

    if counter = 20 [                                       ; at time = 20, NR will fill the gap between the NIR retrofit and the shortfall with the normal 20-year retrofit upgrade. At this time, agents will upgrade to normal_upgrade_benefit level.
      let tempNR (%_EEv_upgrade_at_NR * (1 - EEv ^ diminishing_returns_curve))    ; %_EEv_upgrade_during_NR is the value the agent will gain from a normal retrofit; diminishing_returns equation accounts for diminishing returns of %_EEv_upgrade_during_NR as EEv approaches 100%
      ifelse NIR >= tempNR [ set NR 0 ]                     ; checking to see if the 20% upgrade was already reached by NIR
      [ set NR ( tempNR - NIR ) ]                           ; the normal retrofit will fill the shortfall with NIR

     ;print (word counter ", " EEv ", " tempNR ", " NIR ", " NR)  ; verification
      set counter 0
      ]
  ]
        ;;;;;;;;;;;;;;;;;;;;
        ;;; verification ;;;
        ;;;;;;;;;;;;;;;;;;;;


;    file-open "C:/Users/ericb/Desktop/output/mechanism.csv"
;    file-print (word "ticks, " "Owner_type, " "District?, " "max peer-group, " "mean peer-group, " "min peer-group, " "goal, " "EEv, " "Perceived_benefit, " "Cost, " "counter, " "NR, " "NIR peer-group, ")
;
;    ;;; select one of the following first lines for verification of retrofit decision mechanism for building owner type and District?
;
;    ask turtles-on patches with [pcolor = green][        ; selects one-of Leaders in non-District
;    ask turtles-on patches with [pcolor = lime][         ; selects one-of Leaders in District
;    ask turtles-on patches with [pcolor = blue][         ; selects one-of Conformists in non-District
;    ask turtles-on patches with [pcolor = violet][       ; selects one-of Conformists in District
;    ask turtles-on patches with [pcolor = orange][       ; selects one-of Stigma-avoiders in non-District
;    ask turtles-on patches with [pcolor = red][          ; selects one-of Stigma-avoiders in District
;
;    file-print (word ticks ", " Owner_type ", " District? ", " (max [EEv] of peer-group) ", " (mean [EEv] of peer-group) ", " (min [EEv] of peer-group) ", " goal ", " EEv ", " Perceived_benefit ", " Cost ", " counter ", " NR ", " NIR)
;    ask peer-group [file-print EEv]           ; will print EEv of agents in spatially defined neighborhood or all agents in District
;    ]
;
;    file-close


end


to     calc_neighbor_values

if any? peer-group [                               ; checks to see that there are neighbors to assess as a peer group
  ifelse EEv >= 1 [set cost 1][                            ; stops the cost curve at a maximum value of 1
    set cost ( EEv ^ 3 )                                   ; the cost curve represents the cost per unit increase of EEv. It applies to all agents equally because it is based on the average cost of technology

        ;;;;;;;;;;;;;;;;;;;;
        ;;; verification ;;;
        ;;;;;;;;;;;;;;;;;;;;

;   print ( word  EEv  ", "  cost )                       ; verification
;   show "EEv, cost"
;   file-open "C:/Users/ericb/OneDrive/Documents/2017/Masters Thesis/ABM/cost.csv"
;   file-print ( word  EEv  ", "  cost )                  ; to print EEv and perceived benefit values to an external file

  ]

  if Owner_type = "leader" [
    set goal (max [EEv] of peer-group)            ; the goal is calculated based on the neighbor EEv for each time step
    ifelse EEv >= 1 [set Perceived_benefit 0 ][           ; if EEv is already 1, there is no benefit for investing in a retrofit
      set Perceived_benefit (1 - (EEv ^ 12))              ; this value represents the benefit that this type of building owner expects to gain at each EEv
    ]
    ;;;;;;;;;;;;;;;;;;;;
        ;;; verification ;;;
        ;;;;;;;;;;;;;;;;;;;;

;   print ( word  EEv  ", "  Perceived_benefit )          ; verification
;   show "EEv, Perceived Benefit Leader"
;   file-open "C:/Users/ericb/OneDrive/Documents/2017/Masters Thesis/ABM/leader_PB.csv"
;   file-print ( word  EEv  ", "  Perceived_benefit )     ; to print EEv and perceived benefit values to an external file
    ]

  if Owner_type = "conformist"  [
    set goal (mean [EEv] of peer-group )          ; the goal is calculated based on the neighbor EEv for each time step
    ifelse EEv >= 1 [set Perceived_benefit 0 ][           ; if EEv is already 1, there is no benefit for investing in a retrofit
      set Perceived_benefit (1 - (EEv ^ 1.2))             ; this value represents the benefit that this type of building owner expects to gain at each EEv
    ]
        ;;;;;;;;;;;;;;;;;;;;
        ;;; verification ;;;
        ;;;;;;;;;;;;;;;;;;;;

;   print ( word  EEv  ", "  Perceived_benefit )          ; verification
;   show "EEv, Perceived Benefit Conformist"
;   file-open "C:/Users/ericb/OneDrive/Documents/2017/Masters Thesis/ABM/conformist_PB.csv"
;   file-print ( word  EEv  ", "  Perceived_benefit )     ; to print EEv and perceived benefit values to an external file
  ]

  if Owner_type = "Stigma-avoider"  [
    set goal (min [EEv] of peer-group )           ; the goal is calculated based on the neighbor EEv for each time step
    ifelse EEv >= 1 [set Perceived_benefit 0 ][           ; if EEv is already 1, there is no benefit for investing in a retrofit
      set Perceived_benefit (1 - (EEv ^ 0.2))             ; this value represents the benefit that this type of building owner expects to gain at each EEv
    ]
        ;;;;;;;;;;;;;;;;;;;;
        ;;; verification ;;;
        ;;;;;;;;;;;;;;;;;;;;

;   print ( word  EEv  ", "  Perceived_benefit )          ; verification
;   show "EEv, Perceived Benefit Stigma-avoider"
;   file-open "C:/Users/ericb/OneDrive/Documents/2017/Masters Thesis/ABM/Stigma-avoider_PB.csv"
;   file-print ( word  EEv  ", "  Perceived_benefit )     ; to print EEv and perceived benefit values to an external file
  ]
]
end


to calc_degradation_rate                                  ; Degrade will hold the calculated value of projected EEv loses from degradation

    ask turtles [
    set degrade (.05 * (.25 ^ EEv))                       ; degrade formula y = .05 (1/4)^x ; inefficient buildings degrade at a faster rate, range .05 - .01 per time step
;    show "EEv degrade" print EEv print degrade           ; verification

  ;;;;;;;;;;;;;;;;;;;;;;;
  ;;;verifying degrade;;;
  ;;;;;;;;;;;;;;;;;;;;;;;

  ;show "EEv, degrade"
  ;print ( word self "," EEv "," degrade "," )
  ;file-open "C:/Users/ericb/OneDrive/Documents/2017/Masters Thesis/ABM/degrade.csv"
  ;file-print (word self ", " Owner_type  ", EEv," EEv  ", degrade, "  degrade )          ; to print EEv and degrade values to an external file
  ]

end


to update_values                                  ; update the EE value of the building per time step.



  Ask turtles [                                   ; all turtles will update their EEv. This summarizes all of the building EEv changes that happen in this year.

;    let EEv0 EEv                                 ; for verification printout used below. This is the EEv before updating

    set EEv (EEv + NIR + NR - Degrade)            ; THIS IS THE MAIN EEv UPDATE FORMULA
    truncate EEv                                  ; EEv values cannot be below zero, but they can be above the existing 100% EEv standard
    set counter (counter + 1)                     ; every time step is one year. the counter takes note of how many years since the last normal upgrade


  ;;;;;;;;;;;;;;;;;;;;;;;
  ;;;verifying updates;;;
  ;;;;;;;;;;;;;;;;;;;;;;;

;    let EEv1 EEv                                 ; for verification printout used below. this is the EEv after updating

;    file-open "C:/Users/ericb/Desktop/output/updatemechanism.csv"
;    file-print (word "ticks, " "Owner_type, " "District?, " "EEv0, " "NIR, " "NR, " "Degrade, " "EEv1, ")
;    file-print (word ticks ", " Owner_type ", " District? ", " EEv0 ", " NIR ", " NR ", " Degrade ", " EEv1)
;    file-close
  ]

end

to update_output_values

;;;;;;;;;;;;;;;;;;;;;
;;; For Reporting ;;;
;;;;;;;;;;;;;;;;;;;;;

  if count turtles with [ District? != true and Owner_type = "leader" ] >= 2 [ set mean_LeadND mean [ EEv ] of turtles with [ District? != true and Owner_type = "leader"]]
  if count turtles with [ District? != true and Owner_type = "conformist" ] >= 2 [ set mean_ConformND mean [ EEv ] of turtles with [ District? != true and Owner_type = "conformist"]]
  if count turtles with [ District? != true and Owner_type = "Stigma-avoider" ] >= 2 [ set mean_SaND mean [ EEv ] of turtles with [ District? != true and Owner_type = "Stigma-avoider"]]
  if not any? turtles with [ District? != true and Owner_type = "Stigma-avoider" ][ set mean_SaND "n/a"]
  if not any? turtles with [ District? != true and Owner_type = "leader" ][ set mean_SaD "n/a"]
  if not any? turtles with [ District? != true and Owner_type = "conformist" ][ set mean_SaD "n/a"]
  if not any? turtles with [ District? != true and Owner_type = "Stigma-avoider" ][ set mean_SaD "n/a"]
  if any? turtles with [ District? != true ] [
    set meanND mean [ EEv ] of turtles with [ District? != true ]
    set SdND standard-deviation [EEv] of turtles with [ District? != true ]
  ]

  if count turtles with [ District? = true and Owner_type = "leader" ] >= 2 [  set mean_LeadD mean [ EEv ] of turtles with [ District? = true and Owner_type = "leader" ] ]
  if count turtles with [ District? = true and Owner_type = "conformist" ] >= 2 [   set mean_ConformD mean [ EEv ] of turtles with [ District? = true and Owner_type = "conformist"]]
  if count turtles with [ District? = true and Owner_type = "Stigma-avoider" ] >= 2 [   set mean_SaD mean [ EEv ] of turtles with [ District? = true and Owner_type = "Stigma-avoider"]]
  if not any? turtles with [ District? = true and Owner_type = "leader" ][ set mean_SaD "n/a"]
  if not any? turtles with [ District? = true and Owner_type = "conformist" ][ set mean_SaD "n/a"]
  if not any? turtles with [ District? = true and Owner_type = "Stigma-avoider" ][ set mean_SaD "n/a"]
  if any? turtles with [ District? = true ] [
    set meanD mean [ EEv ] of turtles with [ District? = true ]
    set SdD standard-deviation [EEv] of turtles with [ District? = true ]
    ]

End


to truncate [t]                                        ; this procedures ensures that the value stays between 0 and 1.
  if EEv < 0 [ set EEv 0 ]                             ; it does not make sense for EEv to go below zero

end


to new_owner_type_allowed

  let previous_type Owner_type                          ; FOR VERIFICATION: record the previous building owner type for comparison after the draw

  let draw random 100                                  ; select a random number between 0 and 100
  let leader% ( 100 - %-Leaders )                      ; create a temporary variable to choose between building strategies

  if draw >= leader% [                                 ; leaders can just be assigned because there are no converts.
    set Owner_type "leader"
  ]
  if draw < leader% and draw > %-Stigma-avoiders [            ; compares randomly drawn number to 100 - %-leaders (sets Owner_type leader if greater than than the remainder of 100 - leader slider value)
    set Owner_type "conformist"                          ; maintain the percentage of conformists
  ]
  if draw <= %-Stigma-avoiders [
    set Owner_type "Stigma-avoider"                             ; maintain the percentage of Stigma-avoiders
  ]


    ;;;;;;;;;;;;;;;;;;;;
    ;;; Verification ;;;
    ;;;;;;;;;;;;;;;;;;;;

;   show "draw" print draw
;   show "( 100 - %-Leaders )" print leader%
;   print (word count turtles with [ Owner_type = "leader" ] ", " count turtles with [ Owner_type = "conformist" ]  ", " count turtles with [ Owner_type = "Stigma-avoider" ])

  let after_sale_type Owner_type                         ; Record the building owner type after the draw

  if previous_type != after_sale_type [                ; Compare the owner types
    set owner_change owner_change + 1                  ; Record the number of owner type changes on the interface monitor
;    set pcolor yellow                                  ; To identify the agent that changed owner type
  ]

end


to bring_up_to_code

  if EEv < ( code_min_EEv_level / 100 ) [                  ; To identify whether agent's EEv is below code code
;    print ((code_min_EEv_level / 100 ) - EEv)             ; verification
    set EEv ( code_min_EEv_level / 100 )                   ; If the agent's EEv is not up to code, bring the building up to the value for code (determined by interface slider)
;    set pcolor yellow                                  ; verification: To identify the agent that upgraded to code
;    print Owner_type
  ]

  if EEv < ( code_min_EEv_level / 100 ) and ((( code_min_EEv_level / 100 ) - EEv ) >= %_EEv_upgrade_at_NR ) [
    set counter 0                                       ; If an agent retrofits at or above the same level that they would have normally done, they will not also do a normal retrofit (NR) during this time step

;  print ((code_min_EEv_level / 100 ) - EEv)               ; verification
;    set pcolor red
;    print Owner_type
  ]

end



to update_visuals

  ask turtles [set color 101 + ( EEv * 7 ) ]             ; This sets the color for the agents that reflects their EE value. It gets updated every time step to reflect the updated EE value.

 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; the commented codes below are  ;;;
 ;;; just to easily show how the    ;;;
 ;;; interface plots are calculated ;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  ;;; the coding for the interface plot on upgrades per iteration ;;;

;   if count turtles with [ District? != true and Owner_type = "leader" ] > 2 [plot (mean [ NIR ] of turtles with [ District? != true and Owner_type = "leader" ] + mean [ NR ] of turtles with [ District? != true and Owner_type = "leader"] )]
;   if count turtles with [ District? != true and Owner_type = "conformist" ] > 2 [plot (mean [ NIR ] of turtles with [ District? != true and Owner_type = "conformist" ] + mean [ NR ] of turtles with [ District? != true and Owner_type = "conformist"] )]
;   if count turtles with [ District? != true and Owner_type = "Stigma-avoider" ] > 2 [plot (mean [ NIR ] of turtles with [ District? != true and Owner_type = "Stigma-avoider" ] + mean [ NR ] of turtles with [ District? != true and Owner_type = "Stigma-avoider"] )]
;   if count turtles with [ District? != true ] > 2 [plot (mean [ NIR ] of turtles with [ District? !=  ] + mean [ NR ] of turtles with [ District? != true ] )]
;
;   if count turtles with [ District? = true and Owner_type = "leader" ] > 2 [plot (mean [ NIR ] of turtles with [ District? = true and Owner_type = "leader" ] + mean [ NR ] of turtles with [ District? = true and Owner_type = "leader"] )]
;   if count turtles with [ District? = true and Owner_type = "conformist" ] > 2 [plot (mean [ NIR ] of turtles with [ District? = true and Owner_type = "conformist" ] + mean [ NR ] of turtles with [ District? = true and Owner_type = "conformist"] )]
;   if count turtles with [ District? = true and Owner_type = "Stigma-avoider" ] > 2 [plot (mean [ NIR ] of turtles with [ District? = true and Owner_type = "Stigma-avoider" ] + mean [ NR ] of turtles with [ District? = true and Owner_type = "Stigma-avoider"] )]
;   if count turtles with [ District? = true ] > 2 [plot (mean [ NIR ] of turtles with [ District? =  ] + mean [ NR ] of turtles with [ District? = true ] )]
;

  ;;; the coding for the interface plot on mean EE value per building owner type ;;;

;  if count turtles with [ District? != true and Owner_type = "leader" ] >= 2 [  plot mean [ EEv ] of turtles with [ District? != true and Owner_type = "leader" ]]
;  if count turtles with [ District? != true and Owner_type = "conformist" ] >= 2 [ plot mean [ EEv ] of turtles with [ District? != true and Owner_type = "conformist"]]
;  if count turtles with [ District? != true and Owner_type = "Stigma-avoider" ] >= 2 [ plot mean [ EEv ] of turtles with [ District? != true and Owner_type = "Stigma-avoider"]]
;  plot mean [ EEv ] of turtles with [ District? != true ]
;
;  if count turtles with [ District? = true and Owner_type = "leader" ] >= 2 [  plot mean [ EEv ] of turtles with [ District? = true and Owner_type = "leader" ] ]
;  if count turtles with [ District? = true and Owner_type = "conformist" ] >= 2 [   plot mean [ EEv ] of turtles with [ District? = true and Owner_type = "conformist"]]
;  if count turtles with [ District? = true and Owner_type = "Stigma-avoider" ] >= 2 [   plot mean [ EEv ] of turtles with [ District? = true and Owner_type = "Stigma-avoider"]]
;  plot mean [ EEv ] of turtles with [ District? = true ]

end


to output-initial-results                                       ; This procedure outputs the values after setup to a .csv file

  update_output_values                                          ; populates the values for reporting

  if Print_output? = "no - delete previous output" [            ; Deletes the .csv file when needed (between scenarios)
    if file-exists? "C:/Users/ericb/Desktop/output/output-results.csv" [ file-delete "C:/Users/ericb/Desktop/output/output-results.csv" ]
    ;; Note: When "no" is selected, the file is deleted between scenario runs
  ]

  if Print_output? = "yes" [                                    ; prints the output at each iteration
    ifelse user-yes-or-no? "Do you want to put the headers on the output?" [   ; produces a pop up asking to put headers on the .csv file. Needs to be activated for the first model run of each scenario
      file-open "C:/Users/ericb/Desktop/output/output-results.csv"
      file-print (word "ticks, " "Leader ND avg, " "Conformist ND avg, " "Stigma-avoider ND avg, " "mean all ND, " "SdND, " "Leader D avg, " "Conformist D avg, " "Stigma-avoider D avg, " "mean all D, " "SdD, ")
      file-print ( word ticks ", " mean_LeadND ", "  mean_ConformND ", " mean_SaND ", " meanND ", " SdND ", " mean_LeadD ", "  mean_ConformD ", " mean_SaD ", " meanD  ", " SdND)
      file-close
    ][
      file-open "C:/Users/ericb/Desktop/output/output-results.csv"
      file-print ( word ticks ", " mean_LeadND ", "  mean_ConformND ", " mean_SaND ", " meanND ", " SdND ", " mean_LeadD ", "  mean_ConformD ", " mean_SaD ", " meanD  ", " SdND)
    ]
  ]

end


to output-results                                               ; This procedure outputs the values at every iteration to a .csv file

  update_output_values                                          ; populates the values for reporting

  if Print_output? = "no - delete previous output" [
    if file-exists? "C:/Users/ericb/Desktop/output/output-results.csv" [ file-delete "C:/Users/ericb/Desktop/output/output-results.csv" ]
    if file-exists? "C:/Users/ericb/Desktop/output/mechanism.csv" [ file-delete "C:/Users/ericb/Desktop/output/mechanism.csv" ]
    ;; Note: When "no" is selected, the file is deleted between scenario runs
  ]

  if Print_output? = "yes" [
    let ticklist [ 0 10 20 30 40 50 60 70 80 90 100 150 200 250 300 350 400 450 500 750 1000 ]
    if member? ticks ticklist [
      ;;; use this instead if you want multiples of 10 all the way through maximum-iterations: ticks mod 10 = 0 [
      file-open "C:/Users/ericb/Desktop/output/output-results.csv"
      file-print ( word ticks ", " mean_LeadND ", "  mean_ConformND ", " mean_SaND ", " meanND ", " SdND ", " mean_LeadD ", "  mean_ConformD ", " mean_SaD ", " meanD  ", " SdND)
      file-close
    ]
  ]

end

to reset_temp_values                      ; this procedure resets the temporary values for the next iteration

  ask turtles [

    set Goal 0                            ; goal influenced by peer group in this time step
    set Perceived_benefit 0               ; Perceived benefit of additional EEv unit
    set cost 0                            ; cost of additional EEv unit
    set NIR 0                             ; temporary variable to hold the value of the projected amount of EEv increase due to neighbor influenced upgrades
    set NR 0                              ; temporary variable to hold the value of the normal upgrades above and beyond neighbor influenced upgrades
    set Degrade 0                         ; temporary variable to hold the value of the amount of degradation per time step

  ]

  file-close-all                           ; closes the external file for the current iteration

end
@#$#@#$#@
GRAPHICS-WINDOW
195
78
715
619
-1
-1
10.0
1
10
1
1
1
0
0
0
1
0
50
0
50
0
0
1
ticks
30.0

BUTTON
108
32
172
65
NIL
Setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
117
626
180
659
NIL
Go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
117
664
180
697
NIL
Go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
758
371
1097
550
EEv distribution of all non-District agents
Energy efficiency level
number of agents
0.0
1.2
0.0
1.0
true
true
"set-histogram-num-bars 10" ""
PENS
"Agents (ND)" 1.0 1 -16777216 true "" "histogram [EEv] of turtles with [District? != true]"

PLOT
1105
371
1451
550
EEv distribution of all agents in District
Energy efficiency level
Number of District agents
0.0
1.5
0.0
1.0
true
true
"set-histogram-num-bars 10" ""
PENS
"Agents (D)" 1.0 1 -16777216 true "" "histogram [EEv] of turtles with [District? = true]"

PLOT
1468
351
1835
529
EEv distribution of all agents
Energy efficiency level
number of agents
0.0
1.0
0.0
100.0
true
true
"set-histogram-num-bars 10" ""
PENS
"all" 1.0 1 -16777216 true "" "histogram [EEv] of turtles"

PLOT
758
192
1098
364
Avg. EEv of buildings by owner type, non-District
iterations
mean EE level
0.0
1.0
0.0
1.0
true
true
"" ""
PENS
"Leaders" 1.0 0 -13840069 true "" "if count turtles with [ District? != true and Owner_type = \"leader\" ] >= 2 [  plot mean [ EEv ] of turtles with [ District? != true and Owner_type = \"leader\" ]]"
"Conformists" 1.0 0 -13345367 true "" "if count turtles with [ District? != true and Owner_type = \"conformist\" ] >= 2 [ plot mean [ EEv] of turtles with [ District? != true and Owner_type = \"conformist\"]]"
"Stigma-avoiders" 1.0 0 -955883 true "" "if count turtles with [ District? != true and Owner_type = \"Stigma-avoider\" ] >= 2 [ plot mean [ EEv ] of turtles with [ District? != true and Owner_type = \"Stigma-avoider\"]]"

PLOT
1104
192
1450
365
Avg. EE of buildings by owner type - District
iterations
mean EE level
0.0
1.0
0.0
1.0
true
true
"" ""
PENS
"Leaders" 1.0 0 -13840069 true "" "if count turtles with [ District? = true and Owner_type = \"leader\" ] >= 2 [  plot mean [ EEv ] of turtles with [ District? = true and Owner_type = \"leader\" ] ]"
"Conformists" 1.0 0 -13345367 true "" "if count turtles with [ District? = true and Owner_type = \"conformist\" ] >= 2 [   plot mean [ EEv ] of turtles with [ District? = true and Owner_type = \"conformist\"]]"
"Stigma-avoiders" 1.0 0 -955883 true "" "if count turtles with [ District? = true and Owner_type = \"Stigma-avoider\" ] >= 2 [   plot mean [ EEv ] of turtles with [ District? = true and Owner_type = \"Stigma-avoider\"]]"

SLIDER
27
209
175
242
%-Leaders
%-Leaders
0
100
10
1
1
NIL
HORIZONTAL

SLIDER
27
247
175
280
%-Stigma-avoiders
%-Stigma-avoiders
0
100
10
1
1
NIL
HORIZONTAL

MONITOR
1352
646
1410
691
LeadersND
count turtles with [Owner_type = \"leader\" and District? != true]
17
1
11

MONITOR
1271
646
1349
691
ConformistsND
count turtles with [Owner_type = \"conformist\" and District? != true]
17
1
11

MONITOR
1210
647
1268
692
SaND
count turtles with [Owner_type = \"Stigma-avoider\" and District? != true]
17
1
11

MONITOR
1353
696
1410
741
LeaderD
count turtles with [Owner_type = \"leader\" and District? = true]
17
1
11

MONITOR
1271
696
1349
741
ConformistsD
count turtles with [Owner_type = \"conformist\" and District? = true]
17
1
11

MONITOR
1210
696
1268
741
SaD
count turtles with [Owner_type = \"Stigma-avoider\" and District? = true]
17
1
11

CHOOSER
24
329
176
374
neighborhood
neighborhood
"neighbors" "in-radius 1 neighbors" "in-radius 2 neighbors" "in-radius 3 neighbors"
1

TEXTBOX
481
11
713
71
Agents on this side compare to the EEv of everyone on this side (as a District-wide peer group)
16
0.0
1

TEXTBOX
200
12
483
72
Agents on this side compare to\nthe EEv of their local neighborhood peer group (scale set by chooser)
16
0.0
1

TEXTBOX
15
27
77
56
Setup
24
12.0
1

TEXTBOX
16
288
176
322
Scale of non-District neighborhood peer group
14
0.0
1

TEXTBOX
1214
623
1517
641
Counts by building owner types
14
0.0
1

CHOOSER
368
726
520
771
separate-areas
separate-areas
"no_separation" "District_separation"
1

TEXTBOX
264
737
362
755
Spillover effects
14
0.0
1

CHOOSER
368
627
519
672
new_owner_at_sale
new_owner_at_sale
"yes" "no"
0

TEXTBOX
760
161
1053
192
Neighborhood peer group
16
0.0
1

TEXTBOX
1103
160
1365
179
District-wide peer group
16
0.0
1

CHOOSER
20
542
181
587
Print_output?
Print_output?
"yes" "no - keep previous output" "no - delete previous output"
2

CHOOSER
26
78
173
123
time
time
"100 years" "1000 test"
0

MONITOR
1413
646
1463
691
Total ND
count turtles with [District? != true]
17
1
11

MONITOR
1413
696
1463
741
Total D
count turtles with [District? = true]
17
1
11

MONITOR
937
648
996
693
<= .25
count turtles with [EEv <= .25 and District? != true]
17
1
11

MONITOR
1001
648
1061
693
.25 to < .5
count turtles with [EEv < .5 and District? != true] - count turtles with [EEv < .25 and District? != true]
17
1
11

MONITOR
1065
648
1128
693
.5 to < .75
count turtles with [EEv < .75 and District? != true] - count turtles with [EEv < .5 and District? != true]
17
1
11

MONITOR
1131
648
1189
693
>= .75
count turtles with [EEv >= .75 and District? != true]
17
1
11

TEXTBOX
940
624
1216
645
Building owner counts by EEv quartile
14
0.0
1

MONITOR
937
696
996
741
<= .25
count turtles with [EEv <= .25 and District? = true]
17
1
11

MONITOR
1000
696
1061
741
.25 to < .5
count turtles with [EEv < .5 and District? = true] - count turtles with [EEv < .25 and District? = true]
17
1
11

MONITOR
1064
696
1128
741
.5 to < .75
count turtles with [EEv < .75 and District? = true] - count turtles with [EEv < .5 and District? = true]
17
1
11

MONITOR
1131
696
1190
741
>= .75
count turtles with [EEv >= .75 and District? = true]
17
1
11

SLIDER
20
421
182
454
%_EEv_upgrade_at_NR
%_EEv_upgrade_at_NR
0
1
0.2
.01
1
NIL
HORIZONTAL

TEXTBOX
9
624
90
653
Run
24
12.0
1

TEXTBOX
198
620
356
651
Test Scenarios
24
12.0
1

TEXTBOX
13
382
165
433
Values to change EEv upgrade from NR
14
0.0
1

SLIDER
20
457
182
490
diminishing_returns_curve
diminishing_returns_curve
1
10
7
1
1
NIL
HORIZONTAL

CHOOSER
369
677
521
722
upgrade_to_code_at_sale
upgrade_to_code_at_sale
"yes" "no"
1

TEXTBOX
263
667
413
685
Point of sale
14
0.0
1

SLIDER
527
677
669
710
code_min_EEv_level
code_min_EEv_level
0
100
50
1
1
NIL
HORIZONTAL

TEXTBOX
16
137
204
205
Building owner type proportions \n(note: Conformists make up the remainder)
14
0.0
1

MONITOR
759
556
1097
601
Standard deviation of EEv among all agents, neighbor peer group
SdND
17
1
11

MONITOR
1104
556
1452
601
Standard deviation of EEv among all agents, District-wide  peer group
SdD
17
1
11

BUTTON
17
702
180
735
flag pcolor for verification
ask one-of turtles with [Owner_type = \"leader\" and District? != true and EEv = .5 ][set pcolor green]\nask one-of turtles with [Owner_type = \"leader\" and District? = true and EEv = .5 ][set pcolor lime]\nask one-of turtles with [Owner_type = \"conformist\" and District? != true and EEv = .5 ][set pcolor blue]\nask one-of turtles with [Owner_type = \"conformist\" and District? = true and EEv = .5 ][set pcolor violet]\nask one-of turtles with [Owner_type = \"Stigma-avoider\" and District? != true and EEv = .5 ][set pcolor orange]\nask one-of turtles with [Owner_type = \"Stigma-avoider\" and District? = true and EEv = .5 ][set pcolor red]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
528
627
715
672
# change owner type at point of sale
owner_change
17
1
11

TEXTBOX
767
659
941
693
Neighborhood peer group
14
0.0
1

TEXTBOX
768
712
918
730
District-wide peer group
14
0.0
1

TEXTBOX
756
12
1379
148
LEGEND\nEach patch has one building agent (house icon). The 3 building owner types are randomly distributed across both sides of the world (note: they are not differentiated by color in the graphic; they report values in the plots below)\n\nAgent color is based on EEv level:\n   Bright = high efficient building\n   Dark = low effient building
14
102.6
1

TEXTBOX
10
502
160
536
Select to print output to .csv file
14
0.0
1

@#$#@#$#@
## WHAT IS IT?

NIER (Neighbor Influenced Energy Retrofit)

The development of the NIER model was informed by qualitative research findings and aims to gain a better understanding of how a peer group influences the motivation of different types of building owners to invest in an energy efficiency retrofit.

The qualitative research included interviews with multi-unit residential building owners. They are represented in the NIER model as the following ideal types with different goals and perceptions of the benefits gained from a retrofit.

•	Leaders (compare themselves to the most efficient buildings in their peer group and perceive a broad range of benefits from energy retrofits)

•	Conformists (the majority of owners are norm seeking; the average among peers defines both the goal and the benefits to be gained)

•	Stigma-avoiders (Seek to avoid being defined as the worst energy efficient building among their peers. They hold a base-level perception of benefits, reflecting non-energy efficient priorities building owners may have)

The NIER model explores how the different types of building owners are motivated to retrofit their buildings based on the influence of their peer group, which is represented by scale (local neighborhoods of various sizes and a large-scale, District-wide peer group).

The research that informed this model took an inductive approach that allowed building owners to define terms in ways that made meaning for them. Interviews revealed that building owners consider a broad range of information related to energy efficiency in the decision to retrofit. For this reason, the model represents the packet of information that building owners share with their peers as an Energy Efficiency value (EEv) for their building. Thus, EEv theoretically represents Energy Use Intensity (EUI) as well as other energy efficiency benefits deemed of value by building owners.


For the purposes of this model, agent variables include both building owner characteristics (goals, perceived benefits, and costs) and building-level attributes (EEv and degradation rate).

The model makes the following assumptions to test the interactions between building owner types and their peer groups. Assumptions include perfect, complete, and immediate information sharing and building owners interact with all other building owners in their peer group at every iteration.


## HOW IT WORKS

Every iteration (each iteration represents 1 year through a maximum of 100 years), agents perform the following sequence of procedures:

IF POLICY SCENARIOS ARE ENABLED:
	When agents reach 20 years (on a counter), they will sell the building and execute the policy scenario: allow building owner type to change and/or upgrade the building to the minimum EEv level set by energy-related codes.

MAKE NEIGHBOR INFLUENCED RETROFIT DECISIONS (NIR)
	To do so, agents assess the EEv goal from their peer group (determined by building owner type and peer group scale), calculate perceived benefit and cost of a retrofit (a function of the EEv value at that moment).
	NIR is the motivation from peer groups that is the key component tested by this model. It only produces an influence if the compared value from peer groups is greater than an agent's EEv and if it is economically feasible (perceived benefit > cost).

MAKE A NORMAL RETROFIT DECISION (NR)
	To do so, agents check if their counter has reached 20 years since either the last retrofit or a sale. If so, they then check the NR value as the gain from upgrades they would have normally done without peer influences, due to such factors as the end of the functional life of a material or building component. Finally, they check if the upgrade has not already been done through NIR.

ASSESS THE ANNUAL DEGRADATION RATE
	Building materials and components deteriorate. In doing so, they lose energy efficiency. The rate of energy efficiency loss increases as buildings deteriorate. For example, leaky windows can result in water damage that more rapidly degrades the building envelope. This calculation is the only way that building agents decline in EEv.

UPDATE ENERGY EFFICIENCY VALUE
	Existing EEv is updated with NIR, NR, and degradation. This is the sum of changes in a building every year.

## HOW TO USE IT

Set the base conditions and run the model.
•	Maximum iterations set at 100 years
•	Building owner type proportions: 10% Leaders; 80% Conformists; 10% Stigma-avoiders
•	Small neighbor peer groups: in-radius 1
•	EEv upgrades at normal retrofits: 20% EEv improvement every 20 years with a curve factor of 7
•	Scenarios are not enabled; District and non-District are separated
•	Print_output?: this chooser, on the right of the interface, gives you the option to export the results to a .csv

Run the model with Go forever

Observe the visualization, plots, and counts. You can also work with the data from the .csv file.


## THINGS TO TRY

Run scenarios representing areas with high proportions of Leaders or Stigma-avoiders
•	10% Leaders; 50% Conformists; 40% Stigma-avoiders
•	40% Leaders; 50% Conformists; 10% Stigma-avoiders
(Note what happens to the average EEv of Conformists in the plots)

Run scenarios with different neighborhood scales:
•	in-radius 1
•	in-radius 2
•	in-radius 3
(Note what happens to the difference between the average EEv of Leaders and Stigma-avoiders in the plots and how clustering on the left side of the world (neighborhood peer group) changes as neighborhood scale increases)

Run different point of sale scenarios:
•	enable ownership change at point of sale
(Note what happens to the average EEv of Stigma-avoiders in the District-wide peer group plot)
•	enable bring up to code at point of sale and vary the minumum EEv level required by code (representing upgrades to code standards)
(Note what happens to the average EEv of Stigma-avoiders in the plots and how clustering changes in low energy efficiency neighborhood areas (bottom left of graphic)

Look at the potential of spillover effects between District and non-District areas
•	set separate-areas to "no separation"
(Also try no separation with different neighborhood scales and note how spillover changes as neighborhood scale increases)


## THINGS TO NOTICE

District-wide peer groups quickly raise the average EEv of Leader and Conformist building stocks, but Stigma-avoider buildings are not motivated and decline.

If EEv upgrades at NR are increased to .40, small neighborhood peer groups can successfully motivate Stigma-avoiders.

Allowing building owner type change breaks the negative cycle that leaves Stigma-avoiders behind in District-wide peer groups and raises the average EEv of their building stocks.

Upgrading buildings to a minimum EEv level by enforcing energy code at the point of sale successfully raises the lowest EEv buildings, which are predominantly represented by the building owner type Stigma-avoiders.


## EXTENDING THE MODEL

This model is intended to add qualitative variables of building owner types and peer group scales to existing energy efficiency retrofit adoption models. Extensions to this model can integrate the qualitative contributions of this model to the quantitatively-informed models that look at energy savings and economic feasibility.

Future versions of the model can also include  the effect of a facilitator, sharing different types of energy-related information, or combining network interaction effects with the scale effects represented in this model.


## NETLOGO FEATURES

This model creates a pop up to request whether headers be applied to the output .csv file.


## RELATED MODELS



## CREDITS AND REFERENCES

I am very grateful for the valuable feedback, guidance and support of my committee: Moira Zellner, Ralph Muehleisen, and Michael Siciliano.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="demo 5" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>mean_LeadND</metric>
    <metric>mean_ConformND</metric>
    <metric>mean_LagND</metric>
    <metric>mean_LeadD</metric>
    <metric>mean_ConformD</metric>
    <metric>mean_LagD</metric>
    <enumeratedValueSet variable="blight_strategy">
      <value value="&quot;demolish&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%_EEv_upgrade_during_NR">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="code_efficiency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhood">
      <value value="&quot;in-radius 1 neighbors&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time">
      <value value="&quot;100 baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="diminishing_returns_curve">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new_owner_at_sale">
      <value value="&quot;no&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-Laggards">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="revitalize_percent">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-Leaders">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Print_output?">
      <value value="&quot;no - delete previous output&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="upgrade_to_code_at_sale">
      <value value="&quot;no&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="revitalization_policy">
      <value value="&quot;yes&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="separate-areas">
      <value value="&quot;District_separation&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="reconstruct 17" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>mean_LeadND</metric>
    <metric>mean_ConformND</metric>
    <metric>mean_LagND</metric>
    <metric>mean_LeadD</metric>
    <metric>mean_ConformD</metric>
    <metric>mean_LagD</metric>
    <enumeratedValueSet variable="blight_strategy">
      <value value="&quot;reconstruct&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%_EEv_upgrade_during_NR">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="code_efficiency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhood">
      <value value="&quot;in-radius 1 neighbors&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time">
      <value value="&quot;100 baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="diminishing_returns_curve">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new_owner_at_sale">
      <value value="&quot;no&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-Laggards">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="revitalize_percent">
      <value value="17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-Leaders">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Print_output?">
      <value value="&quot;no - delete previous output&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="upgrade_to_code_at_sale">
      <value value="&quot;no&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="revitalization_policy">
      <value value="&quot;yes&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="separate-areas">
      <value value="&quot;District_separation&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="reconstruct 5" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>mean_LeadND</metric>
    <metric>mean_ConformND</metric>
    <metric>mean_LagND</metric>
    <metric>mean_LeadD</metric>
    <metric>mean_ConformD</metric>
    <metric>mean_LagD</metric>
    <enumeratedValueSet variable="blight_strategy">
      <value value="&quot;reconstruct&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%_EEv_upgrade_during_NR">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="code_efficiency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhood">
      <value value="&quot;in-radius 1 neighbors&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time">
      <value value="&quot;100 baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="diminishing_returns_curve">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new_owner_at_sale">
      <value value="&quot;no&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-Laggards">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="revitalize_percent">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-Leaders">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Print_output?">
      <value value="&quot;no - delete previous output&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="upgrade_to_code_at_sale">
      <value value="&quot;no&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="revitalization_policy">
      <value value="&quot;yes&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="separate-areas">
      <value value="&quot;District_separation&quot;"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
